@@ -1,4 +1,5 @@
 use crate::neural_network::connection_gru::ConnectionGru;
+use crate::neural_network::connection_relu::ConnectionRelu;
 use crate::neural_network::connection_sigmoid::ConnectionSigmoid;
 use crate::neural_network::functions::{fast_sigmoid, fast_tanh};
 use crate::topology::bias::Bias;
@@ -7,9 +8,10 @@ use num::Float;
 use numeric_literals::replace_numeric_literals;
 use std::ops::AddAssign;
 
+#[derive(Debug)]
 pub struct Neuron<T>
 where
-    T: Float + std::cmp::PartialEq + std::cmp::PartialEq + AddAssign,
+    T: Float + std::cmp::PartialEq + std::cmp::PartialEq + AddAssign + Send,
 {
     input: T,
     memory: T,
@@ -18,11 +20,17 @@ where
     pub(crate) prev_reset: T,
     pub(crate) connections_gru: Vec<ConnectionGru<T>>,
     pub(crate) connections_sigmoid: Vec<ConnectionSigmoid<T>>,
+    pub(crate) connections_relu: Vec<ConnectionRelu<T>>,
+}
+
+unsafe impl<T> Send for Neuron<T> where
+    T: Float + std::cmp::PartialEq + std::cmp::PartialEq + AddAssign + Send
+{
 }
 
 impl<T> Neuron<T>
 where
-    T: Float + std::cmp::PartialEq + std::cmp::PartialEq + AddAssign,
+    T: Float + std::cmp::PartialEq + std::cmp::PartialEq + AddAssign + Send,
 {
     pub fn new() -> Neuron<T> {
         Neuron {
@@ -33,6 +41,7 @@ where
             prev_reset: T::zero(),
             connections_gru: vec![],
             connections_sigmoid: vec![],
+            connections_relu: vec![],
         }
     }
 
@@ -53,6 +62,11 @@ where
                 .iter()
                 .map(ConnectionSigmoid::<T>::clone_with_old_pointer)
                 .collect(),
+            connections_relu: self
+                .connections_relu
+                .iter()
+                .map(ConnectionRelu::<T>::clone_with_old_pointer)
+                .collect(),
         }
     }
 
@@ -63,6 +77,9 @@ where
         for connection in &mut self.connections_sigmoid {
             connection.increment_pointer(diff);
         }
+        for connection in &mut self.connections_relu {
+            connection.increment_pointer(diff);
+        }
     }
 
     #[replace_numeric_literals(T::from(literal).unwrap())]
@@ -102,6 +119,10 @@ where
             connection.activate(value);
         }
 
+        for connection in self.connections_relu.iter_mut() {
+            connection.activate(value);
+        }
+
         self.prev_reset = reset_gate;
     }
 
@@ -123,25 +144,26 @@ where
 
     #[inline]
     pub fn increment_state(&mut self, mem: T, inp: T, res: T, upd: T) {
-        self.memory = self.memory + mem;
-        self.input = self.input + inp;
-        self.reset = self.reset + res;
-        self.update = self.update + upd;
+        self.memory += mem;
+        self.input += inp;
+        self.reset += res;
+        self.update += upd;
     }
 
     #[inline]
     pub fn increment_value(&mut self, value: T) {
-        self.input = self.input + value;
+        self.input += value;
     }
 }
 
 impl<T> PartialEq for Neuron<T>
 where
-    T: Float + std::cmp::PartialEq + std::cmp::PartialEq + AddAssign,
+    T: Float + std::cmp::PartialEq + std::cmp::PartialEq + AddAssign + Send,
 {
     fn eq(&self, other: &Neuron<T>) -> bool {
         if self.connections_sigmoid.len() != other.connections_sigmoid.len()
             || self.connections_gru.len() != other.connections_gru.len()
+            || self.connections_relu.len() != other.connections_relu.len()
         {
             return false;
         }
@@ -163,6 +185,15 @@ where
             return false;
         }
 
+        if !self
+            .connections_relu
+            .iter()
+            .zip(other.connections_relu.iter())
+            .all(|(c1, c2)| *c1 == *c2)
+        {
+            return false;
+        }
+
         self.connections_sigmoid
             .iter()
             .zip(other.connections_sigmoid.iter())
