@@ -1,12 +1,12 @@
 use crate::topology::bias::Bias;
-use crate::topology::topology::GeneSmrtPtr;
+use crate::topology::GeneSmrtPtr;
 use num::Float;
 use serde::{Deserialize, Serialize};
 
-#[derive(Clone, Deserialize, Serialize)]
+#[derive(Clone, Deserialize, Serialize, Debug)]
 pub struct BiasAndGenes<T>
 where
-    T: Float,
+    T: Float + Send,
 {
     pub bias: Bias<T>,
     pub genes: Vec<GeneSmrtPtr<T>>,
@@ -14,7 +14,7 @@ where
 
 impl<T> BiasAndGenes<T>
 where
-    T: Float,
+    T: Float + Send,
 {
     pub fn new(bias: Bias<T>) -> BiasAndGenes<T> {
         BiasAndGenes {
